ensure_cursor_table

Function ensure_cursor_table 

pub async fn ensure_cursor_table(pool: &DbPool) -> Result<()>
Ensure the cursor table exists for the active backend.

This should be called once during app startup (e.g. inside AtrgApp::run()) before spawning the Jetstream consumer.